// 包含权限相关的工具方法，注意要在vue的生命周期中调用这些方法，否则会有获取不到权限的问题

import store from "../store";
import { PATH_PERMISSION_NAME } from "../config/pageconfig";

function getPermissionObj() {
  // 支持到二级权限
  const permissions = store.state.user.permissions || [];
  const authObj = {};
  permissions.forEach(ele => {
    authObj[ele.name] = {};
    if (ele.sub_permissions) {
      ele.sub_permissions.forEach(sp => {
        authObj[ele.name][sp.name] = true;
      });
    }
  });
  return authObj;
}

/**
 * 检查页面路径是否有权限
 * @param {*} path
 * @returns
 */
export function checkPathAuth(path) {
  const authObj = getPermissionObj();

  if (path in PATH_PERMISSION_NAME) {
    const authArr = PATH_PERMISSION_NAME[path].split(".");
    const [p, subP] = authArr;
    if (p && subP) {
      return !!authObj[p][subP];
    } else if (p) {
      return !!authObj[p];
    }
    return false;
  }

  return true;
}
