const path = require("path");
const UglifyJsPlugin = require('uglifyjs-webpack-plugin');
const isProduction = process.env.NODE_ENV === 'production';

const isDev = process.env.NODE_ENV === "development";
const plugins = [];
let externalObj = {};
if(isProduction) {
  externalObj = {
    'element-plus': 'ElementPlus',
    vue: "Vue",
    "vue-router": "VueRouter",
    vuex: "Vuex",
    axios: "axios"
  }
}
if (process.env.NODE_ENV === 'production') {
  plugins.push(new UglifyJsPlugin({
    uglifyOptions: {
      warnings: false
    },
    sourceMap: false,
    parallel: true,
  }));
}
const cdn = {
  // 开发环境
  dev: {
    css: [],
    js: []
  },
  // 生产环境
  build: {
    css: [
      "https://unpkg.com/element-plus/lib/theme-chalk/index.css"
    ],
    js: [
      'https://cdn.bootcdn.net/ajax/libs/vue/3.0.11/vue.global.js',
      'https://cdn.bootcdn.net/ajax/libs/vue-router/4.0.6/vue-router.global.js',
      'https://cdn.bootcdn.net/ajax/libs/vuex/4.0.0/vuex.global.js',
      'https://cdn.bootcdn.net/ajax/libs/axios/0.21.1/axios.js',
      'https://cdn.bootcdn.net/ajax/libs/element-plus/1.0.2-beta.44/index.full.js',
      'https://cdn.bootcdn.net/ajax/libs/element-plus/1.0.2-beta.44/umd/locale/zh-cn.js',
      'https://unpkg.com/dayjs/locale/zh-cn.js'
    ]
  }
}
module.exports = {
  outputDir: isDev ? "./dist" : path.resolve("./public/dist/"),
  publicPath: isDev ? "/" : "/dist",
  indexPath: './index.html',
  lintOnSave: false,
  configureWebpack: {
    devServer: {
      proxy: "http://127.0.0.1:8055", //http://localhost:8055
      hot: true,
      disableHostCheck: true,
    },
    resolve: {
      // 配置解析规则
      alias: {
          '@': path.join(__dirname, 'src') // 使用@别名简写src目录所在的绝对路径
      },
    },
    externals: externalObj,
    plugins,
  },
  chainWebpack: config => {
    // 默认不开启 c
    config.plugins.delete("prefetch");

    // 默认不开启 preload
    config.plugins.delete("preload");

    // 修改页面 title
    config.plugin("html").tap(args => {
      args[0].title = "运营管理系统";
      if (isProduction) {
        args[0].cdn = cdn.build
      }
      // if (!isProduction) {
      //     args[0].cdn = cdn.dev
      // }
      return args;
    });
  },
  productionSourceMap: false,

};
